Changelog
=========

1.0.0 (2015-06-05)
------------------

**Dropped Plone 3 compatibility**

* Add TALES field to assignments, allowing users to provide arbitrary conditions [matthewwilkes]

0.4.1 (2014-07-10)
------------------

* Restored MANIFEST file that was destroyed [keul]
* Run import step profile only when needed [keul]

0.4.0 (Unreleased)
------------------

* Do not fail if the configured header was not found [keul]
* Dropped support for ancient Plone versions (Python 2.3) [keul]
* Pyflakes cleanup [keul]
* Now works also on Plone 4.3 [keul]

0.3.0 (2011-10-17)
------------------

* Fixed compatibliy with webserverauth [yurj]
* Updates tests on Plone 4.1 [keul]

0.2.0 (2010-10-04)
------------------

* Fixed project URL on plone.org [keul]
* Added plugin icon [keul]
* Fixed broken tests [keul]
* Added z3c.autoinclude support [keul]

0.1.0a (2010-03-24)
-------------------

* Initial release
